@@ -193,11 +193,14 @@ abstract class Tokenizer
             T_DOC_COMMENT_STRING       => true,
             T_CONSTANT_ENCAPSED_STRING => true,
             T_DOUBLE_QUOTED_STRING     => true,
+            T_START_HEREDOC            => true,
+            T_START_NOWDOC             => true,
             T_HEREDOC                  => true,
             T_NOWDOC                   => true,
             T_END_HEREDOC              => true,
             T_END_NOWDOC               => true,
             T_INLINE_HTML              => true,
+            T_YIELD_FROM               => true,
         ];
 
         $this->numTokens = count($this->tokens);
@@ -618,7 +621,7 @@ abstract class Tokenizer
                 if ($content !== '') {
                     $newContent .= $content;
                     if ($checkEncoding === true) {
-                        // Not using the default encoding, so take a bit more care.
+                        // Not using ASCII encoding, so take a bit more care.
                         $oldLevel = error_reporting();
                         error_reporting(0);
                         $contentLength = iconv_strlen($content, $this->config->encoding);
